numlpa in practice
==================

This section is dedicated to the discovery and use of the package.
You can read the articles in order if you are here for the first time.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   examples
   formats
